# Mixin's

Mixin's are used to add functionality to the base class.

In particular:

- `ParserMixin`: implements the parsing methods from different types (`from_*` methods)
- `ConverterMixin`: implements the conversion methods to different types (`to_*` methods)
- `ComparatorMixin`: implements the comparison operators (`==`, `!=`, `<`, `<=`, `>`, `>=`)

::: iso_week_date.mixin.ParserMixin
    options:
        show_root_full_path: false
        show_root_heading: true

::: iso_week_date.mixin.ConverterMixin
    options:
        show_root_full_path: false
        show_root_heading: true

::: iso_week_date.mixin.ComparatorMixin
    options:
        show_root_full_path: false
        show_root_heading: true
